@@ -2,7 +2,7 @@
 // Syd: rock-solid application kernel
 // src/utils/syd-oci.rs: syd's OCI container runtime
 //
-// Copyright (c) 2024, 2025 Ali Polatel <alip@chesswob.org>
+// Copyright (c) 2024, 2025, 2026 Ali Polatel <alip@chesswob.org>
 // Based in part upon youki which is:
 //     Copyright (c) 2021 youki team
 //     SPDX-License-Identifier: Apache-2.0
@@ -60,7 +60,6 @@ use nix::{
     errno::Errno,
     fcntl::OFlag,
     sys::{
-        prctl::set_name,
         signal,
         signal::kill,
         signalfd::SigSet,
@@ -81,7 +80,7 @@ use oci_spec::runtime::{
 use procfs::process::Namespace;
 use serde_json::to_writer_pretty;
 use syd::{
-    compat::{waitid, WaitStatus},
+    compat::{set_name, waitid, WaitStatus},
     config::ENV_SKIP_SCMP,
     err::{SydError, SydResult},
     hook::Supervisor,
@@ -99,6 +98,8 @@ use tracing_subscriber::layer::SubscriberExt;
 #[cfg(all(
     not(coverage),
     not(feature = "prof"),
+    not(target_os = "android"),
+    not(target_arch = "riscv64"),
     target_page_size_4k,
     target_pointer_width = "64"
 ))]
@@ -208,7 +209,7 @@ impl Executor for SydExecutor {
         ignore_signals(opts).or(Err(ExecutorError::CantHandle("Failed to ignore signals!")))?;
 
         // Run command under the Syd sandbox and exit with the return code.
-        Supervisor::run(sandbox, None, comm, argv, None, None)
+        Supervisor::run(sandbox, None, comm, argv, None)
             .map(i32::from)
             .map(exit)
             .map_err(|err| ExecutorError::Execution(err.into()))?
